..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. include:: ../README.rst

.. toctree::
    :maxdepth: 2

    general/index.rst
    quickstart/index.rst
    tutorials/bootcamp.rst
    tutorials/build-a-repository.rst
    tutorials/understanding-data-models.rst
    tutorials/managing-access.rst
    tutorials/upgrade-marshmallow.rst
    deployment/securing-your-instance.rst
    architecture/infrastructure.rst
    architecture/application.rst
    migrating.rst
    orcid-login.rst
    history.rst
    releases/index.rst
    community/index.rst


.. toctree::
    :hidden:

    tutorials/build-a-module.rst
    tutorials/developing-with-invenio.rst
